@@ -1,8 +1,8 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
-#include "puntateform.h"
 #include "credits.h"
 #include "optionsform.h"
+#include "puntatemain.h"
 
 #include <QtCore/QCoreApplication>
 #include <QProcess>
@@ -11,27 +11,27 @@
 
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), ui(new Ui::MainWindow),
-      puntateForm(0),
       credits(0),
       optionsForm(0),
-      browser(0)
+      browser(0),
+      puntateMain(0)
 {
     ui->setupUi(this);
 
     setAttribute(Qt::WA_Maemo5StackedWindow);
 
-    puntateForm = new PuntateForm(this);
     credits = new Credits(this);
     optionsForm = new OptionsForm(this);
     browser = new Browser(this);
+    puntateMain = new PuntateMain(this);
 }
 
 MainWindow::~MainWindow()
 {
-    if (puntateForm) delete (puntateForm);
     if (credits) delete (credits);
     if (optionsForm) delete (optionsForm);
     if (browser) delete (browser);
+    if (puntateMain) delete (puntateMain);
     delete ui;
 }
 
@@ -162,7 +162,7 @@ void MainWindow::on_actionDonazione_triggered()
 
 void MainWindow::on_actionPuntate_triggered()
 {
-    puntateForm->show();
+    puntateMain->show();
 }
 
 void MainWindow::on_actionCredits_triggered()
