@@ -10,6 +10,7 @@ class PuntateForm;
 class Credits;
 class OptionsForm;
 class Browser;
+class PuntateMain;
 
 namespace Ui {
     class MainWindow;
@@ -72,6 +73,7 @@ private:
     Credits *credits;
     OptionsForm *optionsForm;
     Browser *browser;
+    PuntateMain *puntateMain;
 };
 
 #endif // MAINWINDOW_H
